@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/add_oclass.php,v 1.14 2005/03/20 04:43:36 wurley Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/add_oclass.php,v 1.16 2005/07/22 06:34:55 wurley Exp $
 
 /**
  * Adds an objectClass to the specified dn.
@@ -7,9 +7,10 @@
  * Note, this does not do any schema violation checking. That is
  * performed in add_oclass_form.php.
  *
+ * Variables that come in via common.php
+ *  - server_id
  * Variables that come in as POST vars:
  *  - dn (rawurlencoded)
- *  - server_id
  *  - new_oclass
  *  - new_attrs (array, if any)
  *
@@ -20,16 +21,13 @@
 
 require './common.php';
 
-$server_id = (isset($_POST['server_id']) ? $_POST['server_id'] : '');
-$ldapserver = new LDAPServer($server_id);
-
 if( $ldapserver->isReadOnly() )
 	pla_error( $lang['no_updates_in_read_only_mode'] );
 if( ! $ldapserver->haveAuthInfo())
 	pla_error( $lang['not_enough_login_info'] );
 
 $dn = rawurldecode( $_POST['dn'] );
-$new_oclass = $_POST['new_oclass'];
+$new_oclass = unserialize( rawurldecode( $_POST['new_oclass'] ) );
 $new_attrs = $_POST['new_attrs'];
 
 $encoded_dn = rawurlencode( $dn );
@@ -48,23 +46,19 @@ if( is_array( $new_attrs ) && count( $new_attrs ) > 0 )
 
 		// Check to see if this is a unique Attribute
 		if( $badattr = checkUniqueAttr( $ldapserver, $dn, $attr, array($val) ) ) {
-			$search_href = sprintf('search.php?search=true&form=advanced&server_id=%s&filter=%s=%s',$server_id,$attr,$badattr);
+			$search_href = sprintf('search.php?search=true&form=advanced&server_id=%s&filter=%s=%s',
+				$ldapserver->server_id,$attr,$badattr);
 			pla_error(sprintf( $lang['unique_attr_failed'],$attr,$badattr,$dn,$search_href ) );
 		}
 
 		$new_entry[ $attr ] = $val;
 	}
 
-//echo "<pre>";
-//print_r( $new_entry );
-//exit;
-
 $add_res = @ldap_mod_add( $ldapserver->connect(), $dn, $new_entry );
 
-if( ! $add_res ) {
-	pla_error( $lang['could_not_perform_ldap_mod_add'],ldap_error($ldapserver->connect()),ldap_errno($ldapserver->connect()) );
+if (! $add_res)
+	pla_error($lang['could_not_perform_ldap_mod_add'],ldap_error($ldapserver->connect()),ldap_errno($ldapserver->connect()));
 
-} else {
-	header( "Location: edit.php?server_id=$server_id&dn=$encoded_dn&modified_attrs[]=objectclass" );
-}
+else
+	header(sprintf('Location: edit.php?server_id=%s&dn=%s&modified_attrs[]=objectclass',$ldapserver->server_id,$encoded_dn));
 ?>
