@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/tree.php,v 1.84 2005/03/25 13:04:34 wurley Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/tree.php,v 1.88 2005/09/25 16:11:44 wurley Exp $
 
 /**
  * This script displays the LDAP tree for all the servers that you have
@@ -20,8 +20,6 @@
 
 require './common.php';
 
-global $servers;
-
 // no expire header stuff
 header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
 header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
@@ -45,34 +43,29 @@ $recently_timed_out_servers = array();
 // Set a default META REFRESH value in sec. before determining it
 $meta_refresh_variable = ( session_cache_expire()-1 )*60;
 
-foreach( $servers as $server_id => $server_tree ) {
-	// $ldapserver wont be set, so we'll create it.
-	$ldapserver = new LDAPServer($server_id,true);
+foreach( $ldapservers->GetServerList() as $server_id ) {
+	$ldapserver = $ldapservers->Instance($server_id);
 
 	# Test to see if we should log out the user due to the timeout.
-	if ( $ldapserver->haveAuthInfo() ) {
-		// If time out value has been reached:
-		//	- log out user
-		//	- put $server_id in array of recently timed out servers
-		if ( session_timed_out( $ldapserver ) )
+	if ($ldapserver->haveAuthInfo()) {
+
+		/* If time out value has been reached:
+			- log out user
+			- put $server_id in array of recently timed out servers */
+		if (session_timed_out($ldapserver))
 			array_push($recently_timed_out_servers, $server_id);
-	}
-
-	// Now recalc the new meta refresh.
-	if ( $ldapserver->haveAuthInfo() && isset($servers[ $server_id ][ 'session_timeout' ])) {
-
-		// if the timeout value is less than the previous $meta_refresh_variable value
-		// set $meta_refresh_variable to $servers[ $server_id ][ 'session_timeout' ]
-		if ( ($servers[ $server_id ][ 'session_timeout' ]*60) < $meta_refresh_variable )
-			$meta_refresh_variable = $servers[ $server_id ][ 'session_timeout' ]*60;
 
+		/* if the timeout value is less than the previous $meta_refresh_variable value
+		   set $meta_refresh_variable to $ldapserver->session_timeout */
+		if (($ldapserver->session_timeout*60) < $meta_refresh_variable )
+			$meta_refresh_variable = $ldapserver->session_timeout*60;
 	}
 }
 
-// Close the session for faster page loading (we're done with session data anyway).
-// Unfortunately, now that we dont show a plus '+' for leafs in a tree, we need to keep
-// the session open, so that if we create an entry, it'll cause the refresh of the tree view.
-// Hope this doesnt affect performance...?
+/* Close the session for faster page loading (we're done with session data anyway).
+   Unfortunately, now that we dont show a plus '+' for leafs in a tree, we need to keep
+   the session open, so that if we create an entry, it'll cause the refresh of the tree view.
+   Hope this doesnt affect performance...? */
 // pla_session_close();
 
 include './header.php';
@@ -99,7 +92,7 @@ include './header.php';
 </tr>
 <tr>
 
-<?php if ( ! hide_configuration_management() ) { ?>
+<?php if ( ! $config->GetValue('appearance','hide_configuration_management') ) { ?>
 	<td><img src="images/light.png" alt="<?php echo $lang['light']; ?>" /></td>
 	<td width=50%><nobr><a href="<?php echo $feature_href; ?>" target="new"><?php echo $lang['request_new_feature']; ?></a></nobr></td>
 	<td><img src="images/bug.png" alt="<?php echo $lang['bug']; ?>" /></td>
@@ -118,38 +111,30 @@ include './header.php';
 
 <?php
 
-// We want the std tree function as a fallback
-require_once( 'tree_functions.php' );
+# We want the std tree function as a fallback
+require LIBDIR.'tree_functions.php';
 
-// For each of the configured servers
-foreach( $servers as $server_id => $server_tree ) {
+# For each of the configured servers
+foreach( $ldapservers->GetServerList() as $server_id ) {
+	$ldapserver = $ldapservers->Instance($server_id);
 
-	// $ldapserver wont be set, so we'll create it.
-	$ldapserver = new LDAPServer($server_id);
+	if ($ldapserver->isVisible()) {
+		$filename = get_custom_file($server_id,'tree_functions.php',LIBDIR);
+		require_once($filename);
 
-	if ( $ldapserver->isVisible() )
-	{
-		$filename = get_custom_file( $server_id, 'tree_functions.php' );
-		require_once( $filename );
-
-		call_custom_function( $server_id, 'draw_server_tree' );
+		call_custom_function($server_id,'draw_server_tree');
 	}
-
 }
 
-// Case where user not logged into any server
-if ( $meta_refresh_variable == 0 )
-        $meta_refresh_variable = ( session_cache_expire()-1 )*60;
+# Case where user not logged into any server
+if ($meta_refresh_variable == 0)
+	$meta_refresh_variable = (session_cache_expire()-1)*60;
 
 ?>
 
 <META HTTP-EQUIV="REFRESH" CONTENT="<?php echo $meta_refresh_variable?>">
 
 </table>
-<?php
-//	echo "<pre>"; print_r( $tree );
-?>
-
 </body>
 </html>
 
@@ -163,9 +148,8 @@ exit;
  * @param object $LDAPServer LDAPServer object
  * @param int $level Level to start drawing (defaults to 0)
  */
-function draw_tree_html( $dn, $ldapserver, $level = 0 )
-{
-	global $servers, $tree, $tree_icons, $lang, $search_result_size_limit;
+function draw_tree_html($dn,$ldapserver,$level=0) {
+	global $config, $tree, $tree_icons, $lang;
 
 	$encoded_dn = rawurlencode( $dn );
 	$expand_href = sprintf("expand.php?server_id=%s&amp;dn=%s",$ldapserver->server_id,$encoded_dn);
@@ -209,16 +193,16 @@ function draw_tree_html( $dn, $ldapserver, $level = 0 )
 		<?php }
 
 	} else {
-		$limit = isset( $search_result_size_limit ) ? $search_result_size_limit : 50;
+		$size_limit = $config->GetValue('search','size_limit');
 
 		if( $ldapserver->isLowBandwidth() ) {
 	                $child_count = null;
 		} else {
-	                $child_count = count( get_container_contents( $ldapserver, $dn, $limit+1,
-				'(objectClass=*)', get_tree_deref_setting() ) );
+	                $child_count = count( get_container_contents( $ldapserver, $dn, $size_limit+1,
+				'(objectClass=*)', $config->GetValue('deref','tree')));
 
-			if( $child_count > $limit )
-				$child_count = $limit . '+';
+			if( $child_count > $size_limit )
+				$child_count = $size_limit . '+';
 		}
 
 		if (($child_count === 0) && (! $ldapserver->isShowCreateEnabled())) {
